==> common-web-tools-1.3.0-sources.jar: common/web/tools/webapi/processor/WebApiCheckServiceTokenInterceptor.java <==
package common.web.tools.webapi.processor;


import common.base.tools.exception.ApiException;
import common.web.tools.http.HttpTools;
import common.web.tools.webapi.annotation.WebApiCheckServiceToken;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;

/**
 * Created by Frank.Huang on 2017/1/21.
 */
@Aspect
@Service
public class WebApiCheckServiceTokenInterceptor {
    private static final Logger logger = LoggerFactory.getLogger(WebApiCheckServiceTokenInterceptor.class);


    @Pointcut(value =  "@annotation(common.web.tools.webapi.annotation.WebApiCheckServiceToken)")
    public void webApiCheckServiceToken() { }

    @Before(value = "common.web.tools.webapi.processor.WebApiCheckServiceTokenInterceptor.webApiCheckServiceToken()&&@annotation(wapiCST)")
    public void webApiCheckServiceTokenProcessor(JoinPoint jp, WebApiCheckServiceToken wapiCST) throws ApiException {
        HttpServletRequest request  = (HttpServletRequest) jp.getArgs()[0];
        Long appVer = HttpTools.getLongParameter(request, "appVer");
        if (appVer == null){
            throw new ApiException(-999,2,"App version is empty.");
        }
        
        if (appVer <= wapiCST.minSupportAppVer()) {
            logger.info("Version not support Service token.");
            return;
        }

//        String st = HttpParameterTools.getParameter(request,"st");
//        if (Strings.isNullOrEmpty(st)){
//            logger.warn("Service token is empty");
//            throw new ApiException(HttpCode2.RET_BIZ_ERR,HttpCode2.ERR_BIZ_EMPTY_SERVICE_TOKEN,"Service token is empty");
//        }

//        ServiceToken serviceToken = ServiceTokenTools.decodeServiceToken(st);
//        if (serviceToken == null){
//            logger.error("Invalid Service Token(decode error):{}",st);
//            throw  new ApiException(HttpCode2.RET_BIZ_ERR,HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN,"Invalid service token(decode error)");
//        }
//
//        String did = HttpParameterTools.getParameter(request, "did");
//        if (!did.equalsIgnoreCase(serviceToken.getDid())) {
//            logger.error("Invalid Service Token did[{}-{}]", did, serviceToken.getDid());
//            throw new ApiException(HttpCode2.RET_BIZ_ERR, HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN, "Invalid service token(Forged)");
//        }
    }

}

==> common-web-tools-v3-3.2.3-sources.jar: common/web/tools/webapi/processor/WebApiCheckServiceTokenInterceptor.java <==
package common.web.tools.webapi.processor;


import comm.base.tools.api.exception.ApiException;
import common.web.tools.http.HttpTools;
import common.web.tools.webapi.annotation.WebApiCheckServiceToken;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;

/**
 * Created by Frank.Huang on 2017/1/21.
 */
@Aspect
@Service
public class WebApiCheckServiceTokenInterceptor {
    private static final Logger logger = LoggerFactory.getLogger(WebApiCheckServiceTokenInterceptor.class);


    @Pointcut(value =  "@annotation(common.web.tools.webapi.annotation.WebApiCheckServiceToken)")
    public void webApiCheckServiceToken() { }

    @Before(value = "common.web.tools.webapi.processor.WebApiCheckServiceTokenInterceptor.webApiCheckServiceToken()&&@annotation(wapiCST)")
    public void webApiCheckServiceTokenProcessor(JoinPoint jp, WebApiCheckServiceToken wapiCST) throws ApiException {
        HttpServletRequest request  = (HttpServletRequest) jp.getArgs()[0];
        Long appVer = HttpTools.getLongParameter(request, "appVer");
        if (appVer == null){
            throw new ApiException(-9992,"App version is empty.");
        }
        
        if (appVer <= wapiCST.minSupportAppVer()) {
            logger.info("Version not support Service token.");
            return;
        }

//        String st = HttpParameterTools.getParameter(request,"st");
//        if (Strings.isNullOrEmpty(st)){
//            logger.warn("Service token is empty");
//            throw new ApiException(HttpCode2.RET_BIZ_ERR,HttpCode2.ERR_BIZ_EMPTY_SERVICE_TOKEN,"Service token is empty");
//        }

//        ServiceToken serviceToken = ServiceTokenTools.decodeServiceToken(st);
//        if (serviceToken == null){
//            logger.error("Invalid Service Token(decode error):{}",st);
//            throw  new ApiException(HttpCode2.RET_BIZ_ERR,HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN,"Invalid service token(decode error)");
//        }
//
//        String did = HttpParameterTools.getParameter(request, "did");
//        if (!did.equalsIgnoreCase(serviceToken.getDid())) {
//            logger.error("Invalid Service Token did[{}-{}]", did, serviceToken.getDid());
//            throw new ApiException(HttpCode2.RET_BIZ_ERR, HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN, "Invalid service token(Forged)");
//        }
    }

}
